@@ -1,4 +1,4 @@
-# $Id: Pull.pm 102 2006-04-17 06:04:21Z daisuke $
+# $Id: Pull.pm 96 2005-10-25 02:47:06Z daisuke $
 #
 # Copyright (c) 2005 Daisule Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -13,16 +13,10 @@ use POE;
 sub initialize
 {
     my $self = shift;
-    my %args = @_;
-    $self->SUPER::initialize(%args);
     $self->{DISPATCH_ALARM}       = undef;
-    $self->{JOB_RETRIEVAL_DELAY}  = $args{JobRetrievalDelay}
-        if $args{JobRetrievalDelay};
-    $self->{MAX_SILENCE_INTERVAL} = $args{MaxSilenceInterval}
-        if $args{MaxSilenceInterval};
-
-    $self->{JOB_RETRIEVAL_DELAY}  ||= 30;
-    $self->{MAX_SILENCE_INTERVAL} ||= 900;
+    $self->{JOB_RETRIEVAL_DELAY}  = 30;
+    $self->{MAX_SILENCE_INTERVAL} = 900;
+    $self->SUPER::initialize(@_);
 }
 
 sub states
